import { TypeNameProvider } from '@yellicode/templating';
/**
 * Defines options for dealing with elements that are 'optional', meaning that they have a lower bound of 0.
 */
export declare enum OptionalityModifier {
    /**
     * Don't write any modifier.
     */
    Ignore = 0,
    /**
     * Write a 'null' keyword, for example 'myProperty: string | null;';
     */
    NullKeyword = 1,
    /**
     * Write a question token, for example 'myProperty?: string;';
     */
    QuestionToken = 2,
}
export interface WriterOptions {
    /**
     * The maximum width of generated documentation comments before they are word-wrapped.
     * The default value is 100 characters.
     */
    maxCommentWidth?: number;
    /**
    * Sets an optional TypeNameProvider. By default, the TypeScriptTypeNameProvider is used.
    */
    typeNameProvider?: TypeNameProvider;
}
export declare enum EnumFeatures {
    None = 0,
    JsDocDescription = 1,
    Initializers = 2,
    All = 3,
    AllExceptJsDoc = 2,
}
export interface EnumOptions {
    features?: EnumFeatures;
    prefix?: string;
}
export declare enum ClassFeatures {
    None = 0,
    JsDocDescription = 1,
    Generalizations = 2,
    InterfaceRealizations = 4,
    All = 7,
    AllExceptJsDoc = 6,
}
export interface ClassOptions {
    /**
     * Defines the class features to write. The default is ClassFeatures.All.
     */
    features?: ClassFeatures;
    /**
    * Any additional interface names that the class should implement.
    */
    implements?: string[];
    /**
     * Any additional class names that the class should inherit from.
     */
    inherits?: string[];
    /**
     *  Any string to prefix the class keyword with, such as "export".
     */
    prefix?: string;
}
export declare enum InterfaceFeatures {
    None = 0,
    JsDocDescription = 1,
    Generalizations = 2,
    All = 3,
    AllExceptJsDoc = 2,
}
export interface InterfaceOptions {
    /**
    * Defines the interface features to write. The default is InterfaceFeatures.All.
    */
    features?: InterfaceFeatures;
    /**
    * Any additional interface names that the interface should inherit from.
    */
    inherits?: string[];
    /**
    *  Any string to prefix the interface keyword with, such as "export".
    */
    prefix?: string;
}
export declare enum PropertyFeatures {
    None = 0,
    JsDocDescription = 1,
    AccessModifier = 2,
    ReadonlyModifier = 4,
    OptionalModifier = 8,
    All = 15,
    AllExceptJsDoc = 14,
}
export interface PropertyOptions {
    /**
     * Defines the property features to write. The default is PropertyFeatures.All.
     */
    features?: PropertyFeatures;
    /**
     * Indicates how to deal with properties that have a lower bound of 0. The default is OptionalityModifier.QuestionToken.
     */
    optionality?: OptionalityModifier;
}
export declare enum FunctionFeatures {
    None = 0,
    Comments = 1,
    JsDocDescription = 2,
    JsDocParameters = 4,
    AccessModifier = 8,
    All = 15,
    AllExceptJsDoc = 8,
}
export interface FunctionOptions {
    features?: FunctionFeatures;
    /**
     * Indicates what to write when the return parameter has a lower bound of 0. The default is OptionalityModifier.NullKeyword.
     */
    returnOptionality?: OptionalityModifier;
    /**
     * Indicates what to write when an input parameters has a lower bound of 0. The default is OptionalityModifier.NullKeyword.
     */
    parameterOptionality?: OptionalityModifier;
}
